@@ -115,7 +115,7 @@ class TestModifyChaptersPP(unittest.TestCase):
         self.assertEqual(len(ends), len(titles))
         start = 0
         chapters = []
-        for e, t in zip(ends, titles):
+        for e, t in zip(ends, titles, strict=True):
             chapters.append(self._chapter(start, e, t))
             start = e
         return chapters
