@@ -1,3 +1,4 @@
+import datetime as dt
 import functools
 
 from .common import InfoExtractor
@@ -10,7 +11,7 @@ from ..utils import (
     filter_dict,
     int_or_none,
     orderedSet,
-    unified_timestamp,
+    parse_iso8601,
     url_or_none,
     urlencode_postdata,
     urljoin,
@@ -66,6 +67,14 @@ class AfreecaTVBaseIE(InfoExtractor):
             extensions={'legacy_ssl': True}), display_id,
             'Downloading API JSON', 'Unable to download API JSON')
 
+    @staticmethod
+    def _fixup_thumb(thumb_url):
+        if not url_or_none(thumb_url):
+            return None
+        # Core would determine_ext as 'php' from the url, so we need to provide the real ext
+        # See: https://github.com/yt-dlp/yt-dlp/issues/11537
+        return [{'url': thumb_url, 'ext': 'jpg'}]
+
 
 class AfreecaTVIE(AfreecaTVBaseIE):
     IE_NAME = 'soop'
@@ -79,9 +88,9 @@ class AfreecaTVIE(AfreecaTVBaseIE):
             'uploader_id': 'rlantnghks',
             'uploader': '페이즈으',
             'duration': 10840,
-            'thumbnail': r're:https?://videoimg\.sooplive\.co/.kr/.+',
+            'thumbnail': r're:https?://videoimg\.(?:sooplive\.co\.kr|afreecatv\.com)/.+',
             'upload_date': '20230108',
-            'timestamp': 1673218805,
+            'timestamp': 1673186405,
             'title': '젠지 페이즈',
         },
         'params': {
@@ -94,7 +103,7 @@ class AfreecaTVIE(AfreecaTVBaseIE):
             'id': '20170411_BE689A0E_190960999_1_2_h',
             'ext': 'mp4',
             'title': '혼자사는여자집',
-            'thumbnail': r're:https?://(?:video|st)img\.sooplive\.co\.kr/.+',
+            'thumbnail': r're:https?://(?:video|st)img\.(?:sooplive\.co\.kr|afreecatv\.com)/.+',
             'uploader': '♥이슬이',
             'uploader_id': 'dasl8121',
             'upload_date': '20170411',
@@ -111,7 +120,7 @@ class AfreecaTVIE(AfreecaTVBaseIE):
             'id': '20180327_27901457_202289533_1',
             'ext': 'mp4',
             'title': '[생]빨개요♥ (part 1)',
-            'thumbnail': r're:https?://(?:video|st)img\.sooplive\.co\.kr/.+',
+            'thumbnail': r're:https?://(?:video|st)img\.(?:sooplive\.co\.kr|afreecatv\.com)/.+',
             'uploader': '[SA]서아',
             'uploader_id': 'bjdyrksu',
             'upload_date': '20180327',
@@ -154,8 +163,8 @@ class AfreecaTVIE(AfreecaTVBaseIE):
             'title': ('title', {str}),
             'uploader': ('writer_nick', {str}),
             'uploader_id': ('bj_id', {str}),
-            'duration': ('total_file_duration', {functools.partial(int_or_none, scale=1000)}),
-            'thumbnail': ('thumb', {url_or_none}),
+            'duration': ('total_file_duration', {int_or_none(scale=1000)}),
+            'thumbnails': ('thumb', {self._fixup_thumb}),
         })
 
         entries = []
@@ -178,8 +187,8 @@ class AfreecaTVIE(AfreecaTVBaseIE):
                 'title': f'{common_info.get("title") or "Untitled"} (part {file_num})',
                 'formats': formats,
                 **traverse_obj(file_element, {
-                    'duration': ('duration', {functools.partial(int_or_none, scale=1000)}),
-                    'timestamp': ('file_start', {unified_timestamp}),
+                    'duration': ('duration', {int_or_none(scale=1000)}),
+                    'timestamp': ('file_start', {parse_iso8601(delimiter=' ', timezone=dt.timedelta(hours=9))}),
                 }),
             })
 
@@ -226,19 +235,18 @@ class AfreecaTVCatchStoryIE(AfreecaTVBaseIE):
 
         return self.playlist_result(self._entries(data), video_id)
 
-    @staticmethod
-    def _entries(data):
+    def _entries(self, data):
         # 'files' is always a list with 1 element
         yield from traverse_obj(data, (
             'data', lambda _, v: v['story_type'] == 'catch',
             'catch_list', lambda _, v: v['files'][0]['file'], {
                 'id': ('files', 0, 'file_info_key', {str}),
                 'url': ('files', 0, 'file', {url_or_none}),
-                'duration': ('files', 0, 'duration', {functools.partial(int_or_none, scale=1000)}),
+                'duration': ('files', 0, 'duration', {int_or_none(scale=1000)}),
                 'title': ('title', {str}),
                 'uploader': ('writer_nick', {str}),
                 'uploader_id': ('writer_id', {str}),
-                'thumbnail': ('thumb', {url_or_none}),
+                'thumbnails': ('thumb', {self._fixup_thumb}),
                 'timestamp': ('write_timestamp', {int_or_none}),
             }))
 
@@ -363,7 +371,7 @@ class AfreecaTVLiveIE(AfreecaTVBaseIE):
             'title': channel_info.get('TITLE') or station_info.get('station_title'),
             'uploader': channel_info.get('BJNICK') or station_info.get('station_name'),
             'uploader_id': broadcaster_id,
-            'timestamp': unified_timestamp(station_info.get('broad_start')),
+            'timestamp': parse_iso8601(station_info.get('broad_start'), delimiter=' ', timezone=dt.timedelta(hours=9)),
             'formats': formats,
             'is_live': True,
             'http_headers': {'Referer': url},
