@@ -44,11 +44,11 @@ class CoubIE(InfoExtractor):
         video_id = self._match_id(url)
 
         coub = self._download_json(
-            'http://coub.com/api/v2/coubs/%s.json' % video_id, video_id)
+            f'http://coub.com/api/v2/coubs/{video_id}.json', video_id)
 
         if coub.get('error'):
             raise ExtractorError(
-                '%s said: %s' % (self.IE_NAME, coub['error']), expected=True)
+                '{} said: {}'.format(self.IE_NAME, coub['error']), expected=True)
 
         title = coub['title']
 
@@ -80,7 +80,7 @@ class CoubIE(InfoExtractor):
                     continue
                 formats.append({
                     'url': item_url,
-                    'format_id': '%s-%s-%s' % (HTML5, kind, quality),
+                    'format_id': f'{HTML5}-{kind}-{quality}',
                     'filesize': int_or_none(item.get('size')),
                     'vcodec': 'none' if kind == 'audio' else None,
                     'acodec': 'none' if kind == 'video' else None,
@@ -100,7 +100,7 @@ class CoubIE(InfoExtractor):
         if mobile_url:
             formats.append({
                 'url': mobile_url,
-                'format_id': '%s-audio' % MOBILE,
+                'format_id': f'{MOBILE}-audio',
                 'source_preference': preference_key(MOBILE),
             })
 
