@@ -1,7 +1,6 @@
 import re
 
 from .common import InfoExtractor
-from ..compat import compat_str
 from ..utils import (
     orderedSet,
     parse_duration,
@@ -60,11 +59,11 @@ class MarkizaIE(InfoExtractor):
             info.update({
                 'id': video_id,
                 'title': try_get(
-                    data, lambda x: x['details']['name'], compat_str),
+                    data, lambda x: x['details']['name'], str),
             })
         else:
             info['duration'] = parse_duration(
-                try_get(data, lambda x: x['details']['duration'], compat_str))
+                try_get(data, lambda x: x['details']['duration'], str))
         return info
 
 
@@ -104,7 +103,7 @@ class MarkizaPageIE(InfoExtractor):
 
     @classmethod
     def suitable(cls, url):
-        return False if MarkizaIE.suitable(url) else super(MarkizaPageIE, cls).suitable(url)
+        return False if MarkizaIE.suitable(url) else super().suitable(url)
 
     def _real_extract(self, url):
         playlist_id = self._match_id(url)
@@ -116,7 +115,7 @@ class MarkizaPageIE(InfoExtractor):
             url, playlist_id, expected_status=500)
 
         entries = [
-            self.url_result('http://videoarchiv.markiza.sk/video/%s' % video_id)
+            self.url_result(f'http://videoarchiv.markiza.sk/video/{video_id}')
             for video_id in orderedSet(re.findall(
                 r'(?:initPlayer_|data-entity=["\']|id=["\']player_)(\d+)',
                 webpage))]
