@@ -8,14 +8,14 @@ class NprIE(InfoExtractor):
         'url': 'https://www.npr.org/sections/allsongs/2015/10/21/449974205/new-music-from-beach-house-chairlift-cmj-discoveries-and-more',
         'info_dict': {
             'id': '449974205',
-            'title': 'New Music From Beach House, Chairlift, CMJ Discoveries And More'
+            'title': 'New Music From Beach House, Chairlift, CMJ Discoveries And More',
         },
         'playlist_count': 7,
     }, {
         'url': 'https://www.npr.org/sections/deceptivecadence/2015/10/09/446928052/music-from-the-shadows-ancient-armenian-hymns-and-piano-jazz',
         'info_dict': {
             'id': '446928052',
-            'title': "Songs We Love: Tigran Hamasyan, 'Your Mercy is Boundless'"
+            'title': "Songs We Love: Tigran Hamasyan, 'Your Mercy is Boundless'",
         },
         'playlist': [{
             'md5': '12fa60cb2d3ed932f53609d4aeceabf1',
@@ -121,8 +121,6 @@ class NprIE(InfoExtractor):
                 m3u8_url = traverse_obj(list(raw_json_ld), (..., 'subjectOf', ..., 'embedUrl'), get_all=False)
                 formats = self._extract_m3u8_formats(m3u8_url, media_id, 'mp4', m3u8_id='hls', fatal=False)
 
-            self._sort_formats(formats)
-
             entries.append({
                 'id': media_id,
                 'title': media.get('title', {}).get('$text') or playlist_title,
