@@ -26,7 +26,7 @@ class PodomaticIE(InfoExtractor):
             'uploader_id': 'scienceteachingtips',
             'title': '64.  When the Moon Hits Your Eye',
             'duration': 446,
-        }
+        },
     }, {
         'url': 'http://ostbahnhof.podomatic.com/entry/2013-11-15T16_31_21-08_00',
         'md5': 'd2cf443931b6148e27638650e2638297',
@@ -37,7 +37,7 @@ class PodomaticIE(InfoExtractor):
             'uploader_id': 'ostbahnhof',
             'title': 'Einunddreizig',
             'duration': 3799,
-        }
+        },
     }, {
         'url': 'https://www.podomatic.com/podcasts/scienceteachingtips/episodes/2009-01-02T16_03_35-08_00',
         'only_matching': True,
@@ -48,16 +48,15 @@ class PodomaticIE(InfoExtractor):
         video_id = mobj.group('id')
         channel = mobj.group('channel') or mobj.group('channel_2')
 
-        json_url = (('%s://%s.podomatic.com/entry/embed_params/%s'
-                     + '?permalink=true&rtmp=0') %
-                    (mobj.group('proto'), channel, video_id))
+        json_url = ('{}://{}.podomatic.com/entry/embed_params/{}?permalink=true&rtmp=0'.format(
+            mobj.group('proto'), channel, video_id))
         data_json = self._download_webpage(
             json_url, video_id, 'Downloading video info')
         data = json.loads(data_json)
 
         video_url = data['downloadLink']
         if not video_url:
-            video_url = '%s/%s' % (data['streamer'].replace('rtmp', 'http'), data['mediaLocation'])
+            video_url = '{}/{}'.format(data['streamer'].replace('rtmp', 'http'), data['mediaLocation'])
         uploader = data['podcast']
         title = data['title']
         thumbnail = data['imageLocation']
