@@ -4,7 +4,7 @@ from .jwplatform import JWPlatformIE
 
 class SpiegelIE(InfoExtractor):
     _UUID_RE = r'[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12}'
-    _VALID_URL = r'https?://(?:www\.)?(?:spiegel|manager-magazin)\.de(?:/[^/]+)+/[^/]*-(?P<id>[0-9]+|%s)(?:-embed|-iframe)?(?:\.html)?(?:$|[#?])' % _UUID_RE
+    _VALID_URL = rf'https?://(?:www\.)?(?:spiegel|manager-magazin)\.de(?:/[^/]+)+/[^/]*-(?P<id>[0-9]+|{_UUID_RE})(?:-embed|-iframe)?(?:\.html)?(?:$|[#?])'
     _TESTS = [{
         'url': 'http://www.spiegel.de/video/vulkan-tungurahua-in-ecuador-ist-wieder-aktiv-video-1259285.html',
         'md5': '50c7948883ec85a3e431a0a44b7ad1d6',
@@ -45,7 +45,7 @@ class SpiegelIE(InfoExtractor):
             '_type': 'url_transparent',
             'id': video_id,
             'display_id': video_id,
-            'url': 'jwplatform:%s' % media_id,
+            'url': f'jwplatform:{media_id}',
             'title': self._og_search_title(webpage, default=None),
             'ie_key': JWPlatformIE.ie_key(),
         }
