@@ -13,7 +13,7 @@ class VODPlatformIE(InfoExtractor):
             'id': 'RufMcytHDolTH1MuKHY9Fw',
             'ext': 'mp4',
             'title': 'LBCi News_ النصرة في ضيافة الـ "سي.أن.أن"',
-        }
+        },
     }, {
         'url': 'http://embed.kwikmotion.com/embed/RufMcytHDolTH1MuKHY9Fw',
         'only_matching': True,
@@ -28,7 +28,6 @@ class VODPlatformIE(InfoExtractor):
 
         formats = self._extract_wowza_formats(
             hidden_inputs.get('HiddenmyhHlsLink') or hidden_inputs['HiddenmyDashLink'], video_id, skip_protocols=['f4m', 'smil'])
-        self._sort_formats(formats)
 
         return {
             'id': video_id,
