@@ -1,111 +1,245 @@
 import base64
+import functools
 import hashlib
 import hmac
 import itertools
 import json
 import re
 import time
-import urllib.error
 import urllib.parse
 import uuid
 
 from .common import InfoExtractor
 from .naver import NaverBaseIE
 from .youtube import YoutubeIE
+from ..networking.exceptions import HTTPError
 from ..utils import (
     ExtractorError,
     UserNotLive,
     float_or_none,
     int_or_none,
+    join_nonempty,
+    jwt_decode_hs256,
     str_or_none,
-    traverse_obj,
     try_call,
     update_url_query,
     url_or_none,
 )
+from ..utils.traversal import require, traverse_obj
 
 
 class WeverseBaseIE(InfoExtractor):
     _NETRC_MACHINE = 'weverse'
-    _ACCOUNT_API_BASE = 'https://accountapi.weverse.io/web/api/v2'
+    _ACCOUNT_API_BASE = 'https://accountapi.weverse.io'
+    _CLIENT_PLATFORM = 'WEB'
+    _SIGNING_KEY = b'1b9cb6378d959b45714bec49971ade22e6e24e42'
+    _ACCESS_TOKEN_KEY = 'we2_access_token'
+    _REFRESH_TOKEN_KEY = 'we2_refresh_token'
+    _DEVICE_ID_KEY = 'we2_device_id'
     _API_HEADERS = {
+        'Accept': 'application/json',
+        'Origin': 'https://weverse.io',
         'Referer': 'https://weverse.io/',
-        'WEV-device-Id': str(uuid.uuid4()),
     }
+    _LOGIN_HINT_TMPL = (
+        'You can log in using your refresh token with --username "{}" --password "REFRESH_TOKEN" '
+        '(replace REFRESH_TOKEN with the actual value of the "{}" cookie found in your web browser). '
+        'You can add an optional username suffix, e.g. --username "{}" , '
+        'if you need to manage multiple accounts. ')
+    _LOGIN_ERRORS_MAP = {
+        'login_required': 'This content is only available for logged-in users. ',
+        'invalid_username': '"{}" is not valid login username for this extractor. ',
+        'invalid_password': (
+            'Your password is not a valid refresh token. Make sure that '
+            'you are passing the refresh token, and NOT the access token. '),
+        'no_refresh_token': (
+            'Your access token has expired and there is no refresh token available. '
+            'Refresh your session/cookies in the web browser and try again. '),
+        'expired_refresh_token': (
+            'Your refresh token has expired. Log in to the site again using '
+            'your web browser to get a new refresh token or export fresh cookies. '),
+    }
+    _OAUTH_PREFIX = 'oauth'
+    _oauth_tokens = {}
+    _device_id = None
 
-    def _perform_login(self, username, password):
-        if self._API_HEADERS.get('Authorization'):
-            return
-
-        headers = {
-            'x-acc-app-secret': '5419526f1c624b38b10787e5c10b2a7a',
-            'x-acc-app-version': '2.2.6',
-            'x-acc-language': 'en',
-            'x-acc-service-id': 'weverse',
-            'x-acc-trace-id': str(uuid.uuid4()),
-            'x-clog-user-device-id': str(uuid.uuid4()),
+    @property
+    def _oauth_headers(self):
+        return {
+            **self._API_HEADERS,
+            'X-ACC-APP-SECRET': '5419526f1c624b38b10787e5c10b2a7a',
+            'X-ACC-SERVICE-ID': 'weverse',
+            'X-ACC-TRACE-ID': str(uuid.uuid4()),
         }
-        check_username = self._download_json(
-            f'{self._ACCOUNT_API_BASE}/signup/email/status', None,
-            note='Checking username', query={'email': username}, headers=headers)
-        if not check_username.get('hasPassword'):
-            raise ExtractorError('Invalid username provided', expected=True)
 
-        headers['content-type'] = 'application/json'
+    @functools.cached_property
+    def _oauth_cache_key(self):
+        username = self._get_login_info()[0]
+        if not username:
+            return 'cookies'
+        return join_nonempty(self._OAUTH_PREFIX, username.partition('+')[2])
+
+    @property
+    def _is_logged_in(self):
+        return bool(self._oauth_tokens.get(self._ACCESS_TOKEN_KEY))
+
+    def _access_token_is_valid(self):
+        response = self._download_json(
+            f'{self._ACCOUNT_API_BASE}/api/v1/token/validate', None,
+            'Validating access token', 'Unable to valid access token',
+            expected_status=401, headers={
+                **self._oauth_headers,
+                'Authorization': f'Bearer {self._oauth_tokens[self._ACCESS_TOKEN_KEY]}',
+            })
+        return traverse_obj(response, ('expiresIn', {int}), default=0) > 60
+
+    def _token_is_expired(self, key):
+        is_expired = jwt_decode_hs256(self._oauth_tokens[key])['exp'] - time.time() < 3600
+        if key == self._REFRESH_TOKEN_KEY or not is_expired:
+            return is_expired
+        return not self._access_token_is_valid()
+
+    def _refresh_access_token(self):
+        if not self._oauth_tokens.get(self._REFRESH_TOKEN_KEY):
+            self._report_login_error('no_refresh_token')
+        if self._token_is_expired(self._REFRESH_TOKEN_KEY):
+            self._report_login_error('expired_refresh_token')
+
+        headers = {'Content-Type': 'application/json'}
+        if self._is_logged_in:
+            headers['Authorization'] = f'Bearer {self._oauth_tokens[self._ACCESS_TOKEN_KEY]}'
+
         try:
-            auth = self._download_json(
-                f'{self._ACCOUNT_API_BASE}/auth/token/by-credentials', None, data=json.dumps({
-                    'email': username,
-                    'password': password,
-                }, separators=(',', ':')).encode(), headers=headers, note='Logging in')
+            response = self._download_json(
+                f'{self._ACCOUNT_API_BASE}/api/v1/token/refresh', None,
+                'Refreshing access token', 'Unable to refresh access token',
+                headers={**self._oauth_headers, **headers},
+                data=json.dumps({
+                    'refreshToken': self._oauth_tokens[self._REFRESH_TOKEN_KEY],
+                }, separators=(',', ':')).encode())
         except ExtractorError as e:
-            if isinstance(e.cause, urllib.error.HTTPError) and e.cause.code == 401:
-                raise ExtractorError('Invalid password provided', expected=True)
+            if isinstance(e.cause, HTTPError) and e.cause.status == 401:
+                self._oauth_tokens.clear()
+                if self._oauth_cache_key == 'cookies':
+                    self.cookiejar.clear(domain='.weverse.io', path='/', name=self._ACCESS_TOKEN_KEY)
+                    self.cookiejar.clear(domain='.weverse.io', path='/', name=self._REFRESH_TOKEN_KEY)
+                else:
+                    self.cache.store(self._NETRC_MACHINE, self._oauth_cache_key, self._oauth_tokens)
+                self._report_login_error('expired_refresh_token')
             raise
 
-        WeverseBaseIE._API_HEADERS['Authorization'] = f'Bearer {auth["accessToken"]}'
+        self._oauth_tokens.update(traverse_obj(response, {
+            self._ACCESS_TOKEN_KEY: ('accessToken', {str}, {require('access token')}),
+            self._REFRESH_TOKEN_KEY: ('refreshToken', {str}, {require('refresh token')}),
+        }))
 
-    def _real_initialize(self):
-        if self._API_HEADERS.get('Authorization'):
+        if self._oauth_cache_key == 'cookies':
+            self._set_cookie('.weverse.io', self._ACCESS_TOKEN_KEY, self._oauth_tokens[self._ACCESS_TOKEN_KEY])
+            self._set_cookie('.weverse.io', self._REFRESH_TOKEN_KEY, self._oauth_tokens[self._REFRESH_TOKEN_KEY])
+        else:
+            self.cache.store(self._NETRC_MACHINE, self._oauth_cache_key, self._oauth_tokens)
+
+    def _get_authorization_header(self):
+        if not self._is_logged_in:
+            return {}
+        if self._token_is_expired(self._ACCESS_TOKEN_KEY):
+            self._refresh_access_token()
+        return {'Authorization': f'Bearer {self._oauth_tokens[self._ACCESS_TOKEN_KEY]}'}
+
+    def _report_login_error(self, error_id):
+        error_msg = self._LOGIN_ERRORS_MAP[error_id]
+        username = self._get_login_info()[0]
+
+        if error_id == 'invalid_username':
+            error_msg = error_msg.format(username)
+            username = f'{self._OAUTH_PREFIX}+{username}'
+        elif not username:
+            username = f'{self._OAUTH_PREFIX}+USERNAME'
+
+        raise ExtractorError(join_nonempty(
+            error_msg, self._LOGIN_HINT_TMPL.format(self._OAUTH_PREFIX, self._REFRESH_TOKEN_KEY, username),
+            'Or else you can u', self._login_hint(method='session_cookies')[1:], delim=''), expected=True)
+
+    def _perform_login(self, username, password):
+        if self._is_logged_in:
             return
 
-        token = try_call(lambda: self._get_cookies('https://weverse.io/')['we2_access_token'].value)
-        if not token:
-            self.raise_login_required()
+        if username.partition('+')[0] != self._OAUTH_PREFIX:
+            self._report_login_error('invalid_username')
 
-        WeverseBaseIE._API_HEADERS['Authorization'] = f'Bearer {token}'
+        self._oauth_tokens.update(self.cache.load(self._NETRC_MACHINE, self._oauth_cache_key, default={}))
+        if self._is_logged_in and self._access_token_is_valid():
+            return
+
+        rt_key = self._REFRESH_TOKEN_KEY
+        if not self._oauth_tokens.get(rt_key) or self._token_is_expired(rt_key):
+            if try_call(lambda: jwt_decode_hs256(password)['scope']) != 'refresh':
+                self._report_login_error('invalid_password')
+            self._oauth_tokens[rt_key] = password
+
+        self._refresh_access_token()
+
+    def _real_initialize(self):
+        cookies = self._get_cookies('https://weverse.io/')
+
+        if not self._device_id:
+            self._device_id = traverse_obj(cookies, (self._DEVICE_ID_KEY, 'value')) or str(uuid.uuid4())
+
+        if self._is_logged_in:
+            return
+
+        self._oauth_tokens.update(traverse_obj(cookies, {
+            self._ACCESS_TOKEN_KEY: (self._ACCESS_TOKEN_KEY, 'value'),
+            self._REFRESH_TOKEN_KEY: (self._REFRESH_TOKEN_KEY, 'value'),
+        }))
+        if self._is_logged_in and not self._access_token_is_valid():
+            self._refresh_access_token()
 
     def _call_api(self, ep, video_id, data=None, note='Downloading API JSON'):
         # Ref: https://ssl.pstatic.net/static/wevweb/2_3_2_11101725/public/static/js/2488.a09b41ff.chunk.js
         # From https://ssl.pstatic.net/static/wevweb/2_3_2_11101725/public/static/js/main.e206f7c1.js:
-        key = b'1b9cb6378d959b45714bec49971ade22e6e24e42'
         api_path = update_url_query(ep, {
+            # 'gcc': 'US',
             'appId': 'be4d79eb8fc7bd008ee82c8ec4ff6fd4',
             'language': 'en',
-            'platform': 'WEB',
+            'os': self._CLIENT_PLATFORM,
+            'platform': self._CLIENT_PLATFORM,
             'wpf': 'pc',
         })
-        wmsgpad = int(time.time() * 1000)
-        wmd = base64.b64encode(hmac.HMAC(
-            key, f'{api_path[:255]}{wmsgpad}'.encode(), digestmod=hashlib.sha1).digest()).decode()
-        headers = {'Content-Type': 'application/json'} if data else {}
-        try:
-            return self._download_json(
-                f'https://global.apis.naver.com/weverse/wevweb{api_path}', video_id, note=note,
-                data=data, headers={**self._API_HEADERS, **headers}, query={
-                    'wmsgpad': wmsgpad,
-                    'wmd': wmd,
-                })
-        except ExtractorError as e:
-            if isinstance(e.cause, urllib.error.HTTPError) and e.cause.code == 401:
-                self.raise_login_required(
-                    'Session token has expired. Log in again or refresh cookies in browser')
-            elif isinstance(e.cause, urllib.error.HTTPError) and e.cause.code == 403:
-                raise ExtractorError('Your account does not have access to this content', expected=True)
-            raise
+        for is_retry in (False, True):
+            wmsgpad = int(time.time() * 1000)
+            wmd = base64.b64encode(hmac.HMAC(
+                self._SIGNING_KEY, f'{api_path[:255]}{wmsgpad}'.encode(),
+                digestmod=hashlib.sha1).digest()).decode()
+
+            try:
+                return self._download_json(
+                    f'https://global.apis.naver.com/weverse/wevweb{api_path}', video_id, note=note,
+                    data=data, headers={
+                        **self._API_HEADERS,
+                        **self._get_authorization_header(),
+                        **({'Content-Type': 'application/json'} if data else {}),
+                        'WEV-device-Id': self._device_id,
+                    }, query={
+                        'wmsgpad': wmsgpad,
+                        'wmd': wmd,
+                    })
+            except ExtractorError as e:
+                if is_retry or not isinstance(e.cause, HTTPError):
+                    raise
+                elif self._is_logged_in and e.cause.status == 401:
+                    self._refresh_access_token()
+                    continue
+                elif e.cause.status == 403:
+                    if self._is_logged_in:
+                        raise ExtractorError(
+                            'Your account does not have access to this content', expected=True)
+                    self._report_login_error('login_required')
+                raise
 
     def _call_post_api(self, video_id):
-        return self._call_api(f'/post/v1.0/post-{video_id}?fieldSet=postV1', video_id)
+        path = '' if self._is_logged_in else '/preview'
+        return self._call_api(f'/post/v1.0/post-{video_id}{path}?fieldSet=postV1', video_id)
 
     def _get_community_id(self, channel):
         return str(self._call_api(
@@ -151,11 +285,11 @@ class WeverseBaseIE(InfoExtractor):
             'description': ((('extension', 'mediaInfo', 'body'), 'body'), {str}),
             'uploader': ('author', 'profileName', {str}),
             'uploader_id': ('author', 'memberId', {str}),
-            'creator': ('community', 'communityName', {str}),
+            'creators': ('community', 'communityName', {str}, all),
             'channel_id': (('community', 'author'), 'communityId', {str_or_none}),
             'duration': ('extension', 'video', 'playTime', {float_or_none}),
-            'timestamp': ('publishedAt', {lambda x: int_or_none(x, 1000)}),
-            'release_timestamp': ('extension', 'video', 'onAirStartAt', {lambda x: int_or_none(x, 1000)}),
+            'timestamp': ('publishedAt', {int_or_none(scale=1000)}),
+            'release_timestamp': ('extension', 'video', 'onAirStartAt', {int_or_none(scale=1000)}),
             'thumbnail': ('extension', (('mediaInfo', 'thumbnail', 'url'), ('video', 'thumb')), {url_or_none}),
             'view_count': ('extension', 'video', 'playCount', {int_or_none}),
             'like_count': ('extension', 'video', 'likeCount', {int_or_none}),
@@ -181,7 +315,7 @@ class WeverseBaseIE(InfoExtractor):
 
 
 class WeverseIE(WeverseBaseIE):
-    _VALID_URL = r'https?://(?:www\.|m\.)?weverse.io/(?P<artist>[^/?#]+)/live/(?P<id>[\d-]+)'
+    _VALID_URL = r'https?://(?:www\.|m\.)?weverse\.io/(?P<artist>[^/?#]+)/live/(?P<id>[\d-]+)'
     _TESTS = [{
         'url': 'https://weverse.io/billlie/live/0-107323480',
         'md5': '1fa849f00181eef9100d3c8254c47979',
@@ -195,7 +329,7 @@ class WeverseIE(WeverseBaseIE):
             'channel': 'billlie',
             'channel_id': '72',
             'channel_url': 'https://weverse.io/billlie',
-            'creator': 'Billlie',
+            'creators': ['Billlie'],
             'timestamp': 1666262062,
             'upload_date': '20221020',
             'release_timestamp': 1666262058,
@@ -221,7 +355,7 @@ class WeverseIE(WeverseBaseIE):
             'channel': 'lesserafim',
             'channel_id': '47',
             'channel_url': 'https://weverse.io/lesserafim',
-            'creator': 'LE SSERAFIM',
+            'creators': ['LE SSERAFIM'],
             'timestamp': 1659353400,
             'upload_date': '20220801',
             'release_timestamp': 1659353400,
@@ -285,12 +419,14 @@ class WeverseIE(WeverseBaseIE):
 
         elif live_status == 'is_live':
             video_info = self._call_api(
-                f'/video/v1.0/lives/{api_video_id}/playInfo?preview.format=json&preview.version=v2',
+                f'/video/v1.3/lives/{api_video_id}/playInfo?preview.format=json&preview.version=v2',
                 video_id, note='Downloading live JSON')
             playback = self._parse_json(video_info['lipPlayback'], video_id)
             m3u8_url = traverse_obj(playback, (
                 'media', lambda _, v: v['protocol'] == 'HLS', 'path', {url_or_none}), get_all=False)
-            formats = self._extract_m3u8_formats(m3u8_url, video_id, 'mp4', m3u8_id='hls', live=True)
+            # Live subtitles are not downloadable, but extract to silence "ignoring subs" warning
+            formats, _ = self._extract_m3u8_formats_and_subtitles(
+                m3u8_url, video_id, 'mp4', m3u8_id='hls', live=True)
 
         elif live_status == 'post_live':
             if availability in ('premium_only', 'subscriber_only'):
@@ -301,7 +437,7 @@ class WeverseIE(WeverseBaseIE):
         else:
             infra_video_id = post['extension']['video']['infraVideoId']
             in_key = self._call_api(
-                f'/video/v1.0/vod/{api_video_id}/inKey?preview=false', video_id,
+                f'/video/v1.1/vod/{api_video_id}/inKey?preview=false', video_id,
                 data=b'{}', note='Downloading VOD API key')['inKey']
 
             video_info = self._download_json(
@@ -343,10 +479,9 @@ class WeverseIE(WeverseBaseIE):
 
 
 class WeverseMediaIE(WeverseBaseIE):
-    _VALID_URL = r'https?://(?:www\.|m\.)?weverse.io/(?P<artist>[^/?#]+)/media/(?P<id>[\d-]+)'
+    _VALID_URL = r'https?://(?:www\.|m\.)?weverse\.io/(?P<artist>[^/?#]+)/media/(?P<id>[\d-]+)'
     _TESTS = [{
         'url': 'https://weverse.io/billlie/media/4-116372884',
-        'md5': '8efc9cfd61b2f25209eb1a5326314d28',
         'info_dict': {
             'id': 'e-C9wLSQs6o',
             'ext': 'mp4',
@@ -357,8 +492,9 @@ class WeverseMediaIE(WeverseBaseIE):
             'channel_url': 'https://www.youtube.com/channel/UCyc9sUCxELTDK9vELO5Fzeg',
             'uploader': 'Billlie',
             'uploader_id': '@Billlie',
-            'uploader_url': 'http://www.youtube.com/@Billlie',
+            'uploader_url': 'https://www.youtube.com/@Billlie',
             'upload_date': '20230403',
+            'timestamp': 1680533992,
             'duration': 211,
             'age_limit': 0,
             'playable_in_embed': True,
@@ -371,6 +507,8 @@ class WeverseMediaIE(WeverseBaseIE):
             'thumbnail': 'https://i.ytimg.com/vi/e-C9wLSQs6o/maxresdefault.jpg',
             'categories': ['Entertainment'],
             'tags': 'count:7',
+            'channel_is_verified': True,
+            'heatmap': 'count:100',
         },
     }, {
         'url': 'https://weverse.io/billlie/media/3-102914520',
@@ -385,7 +523,7 @@ class WeverseMediaIE(WeverseBaseIE):
             'channel': 'billlie',
             'channel_id': '72',
             'channel_url': 'https://weverse.io/billlie',
-            'creator': 'Billlie',
+            'creators': ['Billlie'],
             'timestamp': 1662174000,
             'upload_date': '20220903',
             'release_timestamp': 1662174000,
@@ -419,7 +557,7 @@ class WeverseMediaIE(WeverseBaseIE):
 
 
 class WeverseMomentIE(WeverseBaseIE):
-    _VALID_URL = r'https?://(?:www\.|m\.)?weverse.io/(?P<artist>[^/?#]+)/moment/(?P<uid>[\da-f]+)/post/(?P<id>[\d-]+)'
+    _VALID_URL = r'https?://(?:www\.|m\.)?weverse\.io/(?P<artist>[^/?#]+)/moment/(?P<uid>[\da-f]+)/post/(?P<id>[\d-]+)'
     _TESTS = [{
         'url': 'https://weverse.io/secretnumber/moment/66a07e164b56a696ee71c99315ffe27b/post/1-117229444',
         'md5': '87733ac19a54081b7dfc2442036d282b',
@@ -431,7 +569,7 @@ class WeverseMomentIE(WeverseBaseIE):
             'uploader_id': '66a07e164b56a696ee71c99315ffe27b',
             'channel': 'secretnumber',
             'channel_id': '56',
-            'creator': 'SECRET NUMBER',
+            'creators': ['SECRET NUMBER'],
             'duration': 10,
             'upload_date': '20230405',
             'timestamp': 1680653968,
@@ -440,7 +578,6 @@ class WeverseMomentIE(WeverseBaseIE):
             'comment_count': int,
             'availability': 'needs_auth',
         },
-        'skip': 'Moment has expired',
     }]
 
     def _real_extract(self, url):
@@ -463,7 +600,7 @@ class WeverseMomentIE(WeverseBaseIE):
                 'creator': (('community', 'author'), 'communityName', {str}),
                 'channel_id': (('community', 'author'), 'communityId', {str_or_none}),
                 'duration': ('extension', 'moment', 'video', 'uploadInfo', 'playTime', {float_or_none}),
-                'timestamp': ('publishedAt', {lambda x: int_or_none(x, 1000)}),
+                'timestamp': ('publishedAt', {int_or_none(scale=1000)}),
                 'thumbnail': ('extension', 'moment', 'video', 'uploadInfo', 'imageUrl', {url_or_none}),
                 'like_count': ('emotionCount', {int_or_none}),
                 'comment_count': ('commentCount', {int_or_none}),
@@ -515,7 +652,7 @@ class WeverseTabBaseIE(WeverseBaseIE):
 
 
 class WeverseLiveTabIE(WeverseTabBaseIE):
-    _VALID_URL = r'https?://(?:www\.|m\.)?weverse.io/(?P<id>[^/?#]+)/live/?(?:[?#]|$)'
+    _VALID_URL = r'https?://(?:www\.|m\.)?weverse\.io/(?P<id>[^/?#]+)/live/?(?:[?#]|$)'
     _TESTS = [{
         'url': 'https://weverse.io/billlie/live/',
         'playlist_mincount': 55,
@@ -533,7 +670,7 @@ class WeverseLiveTabIE(WeverseTabBaseIE):
 
 
 class WeverseMediaTabIE(WeverseTabBaseIE):
-    _VALID_URL = r'https?://(?:www\.|m\.)?weverse.io/(?P<id>[^/?#]+)/media(?:/|/all|/new)?(?:[?#]|$)'
+    _VALID_URL = r'https?://(?:www\.|m\.)?weverse\.io/(?P<id>[^/?#]+)/media(?:/|/all|/new)?(?:[?#]|$)'
     _TESTS = [{
         'url': 'https://weverse.io/billlie/media/',
         'playlist_mincount': 231,
@@ -557,7 +694,7 @@ class WeverseMediaTabIE(WeverseTabBaseIE):
 
 
 class WeverseLiveIE(WeverseBaseIE):
-    _VALID_URL = r'https?://(?:www\.|m\.)?weverse.io/(?P<id>[^/?#]+)/?(?:[?#]|$)'
+    _VALID_URL = r'https?://(?:www\.|m\.)?weverse\.io/(?P<id>[^/?#]+)/?(?:[?#]|$)'
     _TESTS = [{
         'url': 'https://weverse.io/purplekiss',
         'info_dict': {
@@ -570,7 +707,7 @@ class WeverseLiveIE(WeverseBaseIE):
             'channel': 'purplekiss',
             'channel_id': '35',
             'channel_url': 'https://weverse.io/purplekiss',
-            'creator': 'PURPLE KISS',
+            'creators': ['PURPLE KISS'],
             'timestamp': 1680780892,
             'upload_date': '20230406',
             'release_timestamp': 1680780883,
@@ -583,6 +720,31 @@ class WeverseLiveIE(WeverseBaseIE):
             'live_status': 'is_live',
         },
         'skip': 'Livestream has ended',
+    }, {
+        'url': 'https://weverse.io/lesserafim',
+        'info_dict': {
+            'id': '4-181521628',
+            'ext': 'mp4',
+            'title': r're:심심해서요',
+            'description': '',
+            'uploader': '채채🤎',
+            'uploader_id': 'd49b8b06f3cc1d92d655b25ab27ac2e7',
+            'channel': 'lesserafim',
+            'channel_id': '47',
+            'creators': ['LE SSERAFIM'],
+            'channel_url': 'https://weverse.io/lesserafim',
+            'timestamp': 1728570273,
+            'upload_date': '20241010',
+            'release_timestamp': 1728570264,
+            'release_date': '20241010',
+            'thumbnail': r're:https://phinf\.wevpstatic\.net/.+\.png',
+            'view_count': int,
+            'like_count': int,
+            'comment_count': int,
+            'availability': 'needs_auth',
+            'live_status': 'is_live',
+        },
+        'skip': 'Livestream has ended',
     }, {
         'url': 'https://weverse.io/billlie/',
         'only_matching': True,
